raffle.geom_rw module
=======================

.. .. automodule:: raffle.Geom_Rw
..    :members:
..    :undoc-members:
..    :show-inheritance:

.. autoclass:: raffle.Geom_Rw
   :members:
   :undoc-members:
   :show-inheritance:
